.navbar-default {
	background-color: #444C59;
	border-color: #444C59;
	border-radius: 0;
	margin-bottom: 0;
}
.navbar-default .navbar-brand {
	color: #708999;
	font-weight: 300;
}
.navbar-default .navbar-brand:hover {
	color: #708999;
}
.navbar-default .navbar-nav > .active > a {
	background-color: #4E5666;
	color: #f0f0f0;
}
.navbar-default .navbar-nav > .active > a:hover {
	color: white;
}
.navbar-default .navbar-nav > li > a {
	color: #f0f0f0;
}
.navbar-default .navbar-nav > li > a:hover,
.navbar-default .navbar-nav > li > a:focus {
	background-color: #576173 !important;
	color: white;
}
.nav .open > a, .nav .open > a:hover, .nav .open > a:focus {
	background-color: #576173 !important;
}
.navbar-default .navbar-nav > .open > a,
.navbar-default .navbar-nav > .open > a:hover,
.navbar-default .navbar-nav > .open > a:focus {
	color: #f0f0f0;
}
.tooltip-inner {
	white-space: pre-wrap;
}
textarea:focus,
input[type="text"]:focus,
input[type="password"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="time"]:focus,
input[type="week"]:focus,
input[type="number"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
input[type="color"]:focus,
.uneditable-input:focus {
	border-color: #7F9BAD;
	outline: 0;
	outline: thin dotted \9;
	-webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px #7F9BAD;
	-moz-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px #7F9BAD;
	box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 8px #7F9BAD;
}

.navbar-collapse .btn-group {
	margin-left: 10px;
}
.btn-nav {
	background-color: #ffffff;
	border-color: #ffffff;
	color: #000;
	text-shadow: 0 -1px 0 rgba(0,0,0,0.25);
	background-color: #f5f5f5;
	background-image: -moz-linear-gradient(top,#ffffff,#e6e6e6);
	background-image: -webkit-gradient(linear,0 0,0 100%,from(#ffffff),to(#e6e6e6));
	background-image: -webkit-linear-gradient(top,#ffffff,#e6e6e6);
	background-image: -o-linear-gradient(top,#ffffff,#e6e6e6);
	background-image: linear-gradient(to bottom,#ffffff,#e6e6e6);
	background-repeat: repeat-x;
	filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ffffffff', endColorstr='#ffe5e5e5', GradientType=0);
	border-color: #e6e6e6 #e6e6e6 #bfbfbf;
	border-color: rgba(0,0,0,0.1) rgba(0,0,0,0.1) rgba(0,0,0,0.25);

	margin-top: 8px;
}
.btn-nav:hover,
.btn-nav:focus {
	text-decoration: none;
	background-position: 0 -15px;
	-webkit-transition: background-position .1s linear;
	-moz-transition: background-position .1s linear;
	-o-transition: background-position .1s linear;
	transition: background-position .1s linear;
}
.btn-nav:hover,
.btn-nav:focus {
	background-color: #e6e6e6;
}
.btn-nav:active,
.btn-nav.active,
.btn-nav.active:hover {
	background-color: #f2f2f2;
	border-color: #e6e6e6;
}
.btn-nav.disabled:hover,
.btn-nav.disabled:focus,
.btn-nav.disabled:active,
.btn-nav.disabled.active,
.btn-nav[disabled] .btn-nav:hover,
.btn-nav[disabled] .btn-nav:focus,
.btn-nav[disabled] .btn-nav:active,
.btn-nav[disabled] .btn-nav.active {
	background-color: #ffffff;
	border-color: #ffffff;
}

/* http://stackoverflow.com/questions/22276536/typeahead-js-interferes-with-bootstrap-input-groups */
.twitter-typeahead {
	float:left;
	width:100%;
}
.input-group .twitter-typeahead .form-control:not(:first-child):not(:last-child) {
	border-radius: 4px 0px 0px 4px;
}
.input-group-lg .twitter-typeahead input.form-control {
	font-size: 18px;
	height: 46px;
}

.badge {
	padding: 3px 9px 3px 9px;
	font-size: 12px;
	font-weight: bold;
	font-family: Helvetica, Arial, sans-serif;
	white-space: nowrap;
	color: #ffffff;
	background-color: #999999;
	-webkit-border-radius: 9px;
	-moz-border-radius: 9px;
	border-radius: 9px;
}
.badge-danger {
	background-color: #dd0000;
}
td {
	vertical-align: middle !important;
}
.btn-file {
	position: relative;
	overflow: hidden;
}
.btn-file input[type=file] {
	position: absolute;
	top: 0;
	right: 0;
	filter: alpha(opacity=0);
	opacity: 0;
	display: block;
}
